# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.link_description import LinkDescription
from paypalserversdk.models.transaction_details import TransactionDetails


class SearchResponse(object):

    """Implementation of the 'Search Response' model.

    The search response information.

    Attributes:
        transaction_details (List[TransactionDetails]): An array of
            transaction detail objects.
        account_number (str): The merchant account number.
        start_date (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are optional. Note: The
            regular expression provides guidance but does not reject all
            invalid dates.
        end_date (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are optional. Note: The
            regular expression provides guidance but does not reject all
            invalid dates.
        last_refreshed_datetime (str): The date and time, in [Internet date
            and time format](https://tools.ietf.org/html/rfc3339#section-5.6).
            Seconds are required while fractional seconds are optional. Note:
            The regular expression provides guidance but does not reject all
            invalid dates.
        page (int): A zero-relative index of transactions.
        total_items (int): The total number of transactions as an integer
            beginning with the specified `page` in the full result and not
            just in this response.
        total_pages (int): The total number of pages, as an `integer`, when
            the `total_items` is divided into pages of the specified
            `page_size`.
        links (List[LinkDescription]): An array of request-related [HATEOAS
            links](/api/rest/responses/#hateoas-links).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "transaction_details": 'transaction_details',
        "account_number": 'account_number',
        "start_date": 'start_date',
        "end_date": 'end_date',
        "last_refreshed_datetime": 'last_refreshed_datetime',
        "page": 'page',
        "total_items": 'total_items',
        "total_pages": 'total_pages',
        "links": 'links'
    }

    _optionals = [
        'transaction_details',
        'account_number',
        'start_date',
        'end_date',
        'last_refreshed_datetime',
        'page',
        'total_items',
        'total_pages',
        'links',
    ]

    def __init__(self,
                 transaction_details=APIHelper.SKIP,
                 account_number=APIHelper.SKIP,
                 start_date=APIHelper.SKIP,
                 end_date=APIHelper.SKIP,
                 last_refreshed_datetime=APIHelper.SKIP,
                 page=APIHelper.SKIP,
                 total_items=APIHelper.SKIP,
                 total_pages=APIHelper.SKIP,
                 links=APIHelper.SKIP):
        """Constructor for the SearchResponse class"""

        # Initialize members of the class
        if transaction_details is not APIHelper.SKIP:
            self.transaction_details = transaction_details 
        if account_number is not APIHelper.SKIP:
            self.account_number = account_number 
        if start_date is not APIHelper.SKIP:
            self.start_date = start_date 
        if end_date is not APIHelper.SKIP:
            self.end_date = end_date 
        if last_refreshed_datetime is not APIHelper.SKIP:
            self.last_refreshed_datetime = last_refreshed_datetime 
        if page is not APIHelper.SKIP:
            self.page = page 
        if total_items is not APIHelper.SKIP:
            self.total_items = total_items 
        if total_pages is not APIHelper.SKIP:
            self.total_pages = total_pages 
        if links is not APIHelper.SKIP:
            self.links = links 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        transaction_details = None
        if dictionary.get('transaction_details') is not None:
            transaction_details = [TransactionDetails.from_dictionary(x) for x in dictionary.get('transaction_details')]
        else:
            transaction_details = APIHelper.SKIP
        account_number = dictionary.get("account_number") if dictionary.get("account_number") else APIHelper.SKIP
        start_date = dictionary.get("start_date") if dictionary.get("start_date") else APIHelper.SKIP
        end_date = dictionary.get("end_date") if dictionary.get("end_date") else APIHelper.SKIP
        last_refreshed_datetime = dictionary.get("last_refreshed_datetime") if dictionary.get("last_refreshed_datetime") else APIHelper.SKIP
        page = dictionary.get("page") if dictionary.get("page") else APIHelper.SKIP
        total_items = dictionary.get("total_items") if dictionary.get("total_items") else APIHelper.SKIP
        total_pages = dictionary.get("total_pages") if dictionary.get("total_pages") else APIHelper.SKIP
        links = None
        if dictionary.get('links') is not None:
            links = [LinkDescription.from_dictionary(x) for x in dictionary.get('links')]
        else:
            links = APIHelper.SKIP
        # Return an object of this model
        return cls(transaction_details,
                   account_number,
                   start_date,
                   end_date,
                   last_refreshed_datetime,
                   page,
                   total_items,
                   total_pages,
                   links)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'transaction_details={(self.transaction_details if hasattr(self, "transaction_details") else None)!r}, '
                f'account_number={(self.account_number if hasattr(self, "account_number") else None)!r}, '
                f'start_date={(self.start_date if hasattr(self, "start_date") else None)!r}, '
                f'end_date={(self.end_date if hasattr(self, "end_date") else None)!r}, '
                f'last_refreshed_datetime={(self.last_refreshed_datetime if hasattr(self, "last_refreshed_datetime") else None)!r}, '
                f'page={(self.page if hasattr(self, "page") else None)!r}, '
                f'total_items={(self.total_items if hasattr(self, "total_items") else None)!r}, '
                f'total_pages={(self.total_pages if hasattr(self, "total_pages") else None)!r}, '
                f'links={(self.links if hasattr(self, "links") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'transaction_details={(self.transaction_details if hasattr(self, "transaction_details") else None)!s}, '
                f'account_number={(self.account_number if hasattr(self, "account_number") else None)!s}, '
                f'start_date={(self.start_date if hasattr(self, "start_date") else None)!s}, '
                f'end_date={(self.end_date if hasattr(self, "end_date") else None)!s}, '
                f'last_refreshed_datetime={(self.last_refreshed_datetime if hasattr(self, "last_refreshed_datetime") else None)!s}, '
                f'page={(self.page if hasattr(self, "page") else None)!s}, '
                f'total_items={(self.total_items if hasattr(self, "total_items") else None)!s}, '
                f'total_pages={(self.total_pages if hasattr(self, "total_pages") else None)!s}, '
                f'links={(self.links if hasattr(self, "links") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CaptureType(object):

    """Implementation of the 'Capture Type' enum.

    The type of capture.

    Attributes:
        OUTSTANDING_BALANCE: The outstanding balance that the subscriber must
            clear.

    """
    OUTSTANDING_BALANCE = 'OUTSTANDING_BALANCE'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaymentTokenStatus(object):

    """Implementation of the 'Payment Token Status' enum.

    The status of the payment token.

    Attributes:
        CREATED: A setup token is initialized with minimal information, more
            data must be added to the setup-token to be vaulted
        PAYER_ACTION_REQUIRED: A contingency on payer approval is required
            before the payment method can be saved.
        APPROVED: Setup token is ready to be vaulted. If a buyer approval
            contigency was returned, it is has been approved.
        VAULTED: The payment token has been vaulted.
        TOKENIZED: A vaulted payment method token has been tokenized for short
            term (one time) use.

    """
    CREATED = 'CREATED'

    PAYER_ACTION_REQUIRED = 'PAYER_ACTION_REQUIRED'

    APPROVED = 'APPROVED'

    VAULTED = 'VAULTED'

    TOKENIZED = 'TOKENIZED'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CallbackEvents(object):

    """Implementation of the 'Callback Events' enum.

    CallBack event.

    Attributes:
        SHIPPING_ADDRESS: When Buyer changes or selects the shipping address
            on the PayPal/Venmo buyer approval flow , PayPal/Venmo will call
            merchant with the callback URL to update order totals.
        SHIPPING_OPTIONS: When Buyer changes or selects the shipping options
            on the PayPal/Venmo buyer approval flow , PayPal/Venmo will call
            merchant with the callback URL to update order totals.

    """
    SHIPPING_ADDRESS = 'SHIPPING_ADDRESS'

    SHIPPING_OPTIONS = 'SHIPPING_OPTIONS'




# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper
from paypalserversdk.models.money import Money


class PaymentPreferencesOverride(object):

    """Implementation of the 'Payment Preferences Override' model.

    The payment preferences to override at subscription level.

    Attributes:
        auto_bill_outstanding (bool): Indicates whether to automatically bill
            the outstanding amount in the next billing cycle.
        setup_fee (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.
        setup_fee_failure_action (SetupFeeFailureAction): The action to take
            on the subscription if the initial payment for the setup fails.
        payment_failure_threshold (int): The maximum number of payment
            failures before a subscription is suspended. For example, if
            `payment_failure_threshold` is `2`, the subscription automatically
            updates to the `SUSPEND` state if two consecutive payments fail.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "auto_bill_outstanding": 'auto_bill_outstanding',
        "setup_fee": 'setup_fee',
        "setup_fee_failure_action": 'setup_fee_failure_action',
        "payment_failure_threshold": 'payment_failure_threshold'
    }

    _optionals = [
        'auto_bill_outstanding',
        'setup_fee',
        'setup_fee_failure_action',
        'payment_failure_threshold',
    ]

    def __init__(self,
                 auto_bill_outstanding=APIHelper.SKIP,
                 setup_fee=APIHelper.SKIP,
                 setup_fee_failure_action=APIHelper.SKIP,
                 payment_failure_threshold=APIHelper.SKIP):
        """Constructor for the PaymentPreferencesOverride class"""

        # Initialize members of the class
        if auto_bill_outstanding is not APIHelper.SKIP:
            self.auto_bill_outstanding = auto_bill_outstanding 
        if setup_fee is not APIHelper.SKIP:
            self.setup_fee = setup_fee 
        if setup_fee_failure_action is not APIHelper.SKIP:
            self.setup_fee_failure_action = setup_fee_failure_action 
        if payment_failure_threshold is not APIHelper.SKIP:
            self.payment_failure_threshold = payment_failure_threshold 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        auto_bill_outstanding = dictionary.get("auto_bill_outstanding") if "auto_bill_outstanding" in dictionary.keys() else APIHelper.SKIP
        setup_fee = Money.from_dictionary(dictionary.get('setup_fee')) if 'setup_fee' in dictionary.keys() else APIHelper.SKIP
        setup_fee_failure_action = dictionary.get("setup_fee_failure_action") if dictionary.get("setup_fee_failure_action") else APIHelper.SKIP
        payment_failure_threshold = dictionary.get("payment_failure_threshold") if dictionary.get("payment_failure_threshold") else APIHelper.SKIP
        # Return an object of this model
        return cls(auto_bill_outstanding,
                   setup_fee,
                   setup_fee_failure_action,
                   payment_failure_threshold)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'auto_bill_outstanding={(self.auto_bill_outstanding if hasattr(self, "auto_bill_outstanding") else None)!r}, '
                f'setup_fee={(self.setup_fee if hasattr(self, "setup_fee") else None)!r}, '
                f'setup_fee_failure_action={(self.setup_fee_failure_action if hasattr(self, "setup_fee_failure_action") else None)!r}, '
                f'payment_failure_threshold={(self.payment_failure_threshold if hasattr(self, "payment_failure_threshold") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'auto_bill_outstanding={(self.auto_bill_outstanding if hasattr(self, "auto_bill_outstanding") else None)!s}, '
                f'setup_fee={(self.setup_fee if hasattr(self, "setup_fee") else None)!s}, '
                f'setup_fee_failure_action={(self.setup_fee_failure_action if hasattr(self, "setup_fee_failure_action") else None)!s}, '
                f'payment_failure_threshold={(self.payment_failure_threshold if hasattr(self, "payment_failure_threshold") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class PaypalWalletStoredCredential(object):

    """Implementation of the 'PayPal Wallet Stored Credential' model.

    Provides additional details to process a payment using the PayPal wallet
    billing agreement or a vaulted payment method that has been stored or is
    intended to be stored.

    Attributes:
        payment_initiator (PaymentInitiator): The person or party who
            initiated or triggered the payment.
        charge_pattern (UsagePattern): DEPRECATED. Expected business/pricing
            model for the billing agreement, Please use usage_pattern instead.
        usage_pattern (UsagePattern): Expected business/pricing model for the
            billing agreement.
        usage (StoredPaymentSourceUsageType): Indicates if this is a `first`
            or `subsequent` payment using a stored payment source (also
            referred to as stored credential or card on file).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_initiator": 'payment_initiator',
        "charge_pattern": 'charge_pattern',
        "usage_pattern": 'usage_pattern',
        "usage": 'usage'
    }

    _optionals = [
        'charge_pattern',
        'usage_pattern',
        'usage',
    ]

    def __init__(self,
                 payment_initiator=None,
                 charge_pattern=APIHelper.SKIP,
                 usage_pattern=APIHelper.SKIP,
                 usage='DERIVED'):
        """Constructor for the PaypalWalletStoredCredential class"""

        # Initialize members of the class
        self.payment_initiator = payment_initiator 
        if charge_pattern is not APIHelper.SKIP:
            self.charge_pattern = charge_pattern 
        if usage_pattern is not APIHelper.SKIP:
            self.usage_pattern = usage_pattern 
        self.usage = usage 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_initiator = dictionary.get("payment_initiator") if dictionary.get("payment_initiator") else None
        charge_pattern = dictionary.get("charge_pattern") if dictionary.get("charge_pattern") else APIHelper.SKIP
        usage_pattern = dictionary.get("usage_pattern") if dictionary.get("usage_pattern") else APIHelper.SKIP
        usage = dictionary.get("usage") if dictionary.get("usage") else 'DERIVED'
        # Return an object of this model
        return cls(payment_initiator,
                   charge_pattern,
                   usage_pattern,
                   usage)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'payment_initiator={self.payment_initiator!r}, '
                f'charge_pattern={(self.charge_pattern if hasattr(self, "charge_pattern") else None)!r}, '
                f'usage_pattern={(self.usage_pattern if hasattr(self, "usage_pattern") else None)!r}, '
                f'usage={(self.usage if hasattr(self, "usage") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'payment_initiator={self.payment_initiator!s}, '
                f'charge_pattern={(self.charge_pattern if hasattr(self, "charge_pattern") else None)!s}, '
                f'usage_pattern={(self.usage_pattern if hasattr(self, "usage_pattern") else None)!s}, '
                f'usage={(self.usage if hasattr(self, "usage") else None)!s})')
